#[repr(transparent)]pub struct Capability0(pub u32);Expand description
DCP capability 0 register
Tuple Fields
0: u32Implementations
Sourceimpl Capability0
impl Capability0
Sourcepub const fn num_keys(&self) -> u8
pub const fn num_keys(&self) -> u8
Encoded value indicating the number of key-storage locations implemented in the design
Sourcepub const fn set_num_keys(&mut self, val: u8)
pub const fn set_num_keys(&mut self, val: u8)
Encoded value indicating the number of key-storage locations implemented in the design
Sourcepub const fn num_channels(&self) -> u8
pub const fn num_channels(&self) -> u8
Encoded value indicating the number of channels implemented in the design
Sourcepub const fn set_num_channels(&mut self, val: u8)
pub const fn set_num_channels(&mut self, val: u8)
Encoded value indicating the number of channels implemented in the design
Sourcepub const fn disable_unique_key(&self) -> bool
pub const fn disable_unique_key(&self) -> bool
Write to a 1 to disable the per-device unique key
Sourcepub const fn set_disable_unique_key(&mut self, val: bool)
pub const fn set_disable_unique_key(&mut self, val: bool)
Write to a 1 to disable the per-device unique key
Sourcepub const fn disable_decrypt(&self) -> bool
pub const fn disable_decrypt(&self) -> bool
Write to 1 to disable the decryption
Sourcepub const fn set_disable_decrypt(&mut self, val: bool)
pub const fn set_disable_decrypt(&mut self, val: bool)
Write to 1 to disable the decryption