nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Capability1

Struct Capability1 

#[repr(transparent)]
pub struct Capability1(pub u32);
DCP capability 1 register

Tuple Fields

0: u32

Implementations

Source

impl Capability1

pub const fn cipher_algorithms(&self) -> CipherAlgorithms

One-hot field indicating which cipher algorithms are available

pub const fn set_cipher_algorithms(&mut self, val: CipherAlgorithms)

One-hot field indicating which cipher algorithms are available

pub const fn hash_algorithms(&self) -> HashAlgorithms

One-hot field indicating which hashing features are implemented in the hardware

pub const fn set_hash_algorithms(&mut self, val: HashAlgorithms)

One-hot field indicating which hashing features are implemented in the hardware