#[repr(transparent)]pub struct Ch1optsTog(pub u32);Expand description
DCP channel 1 options register
Tuple Fields
0: u32Implementations
Sourceimpl Ch1optsTog
impl Ch1optsTog
Sourcepub const fn recovery_timer(&self) -> u16
pub const fn recovery_timer(&self) -> u16
This field indicates the recovery time for the channel
Sourcepub const fn set_recovery_timer(&mut self, val: u16)
pub const fn set_recovery_timer(&mut self, val: u16)
This field indicates the recovery time for the channel