#[repr(transparent)]pub struct Ch3opts(pub u32);Expand description
DCP channel 3 options register
Tuple Fields
0: u32Implementations
Sourceimpl Ch3opts
impl Ch3opts
Sourcepub const fn recovery_timer(&self) -> u16
pub const fn recovery_timer(&self) -> u16
This field indicates the recovery time for the channel
Sourcepub const fn set_recovery_timer(&mut self, val: u16)
pub const fn set_recovery_timer(&mut self, val: u16)
This field indicates the recovery time for the channel