#[repr(transparent)]pub struct ChannelctrlSet(pub u32);Expand description
DCP channel control register
Tuple Fields
0: u32Implementations
Sourceimpl ChannelctrlSet
impl ChannelctrlSet
Sourcepub const fn enable_channel(&self) -> ChannelctrlSetEnableChannel
pub const fn enable_channel(&self) -> ChannelctrlSetEnableChannel
Setting a bit in this field enables the DMA channel associated with it
Sourcepub const fn set_enable_channel(&mut self, val: ChannelctrlSetEnableChannel)
pub const fn set_enable_channel(&mut self, val: ChannelctrlSetEnableChannel)
Setting a bit in this field enables the DMA channel associated with it
Sourcepub const fn high_priority_channel(&self) -> ChannelctrlSetHighPriorityChannel
pub const fn high_priority_channel(&self) -> ChannelctrlSetHighPriorityChannel
Setting a bit in this field causes the corresponding channel to have high-priority arbitration
Sourcepub const fn set_high_priority_channel(
&mut self,
val: ChannelctrlSetHighPriorityChannel,
)
pub const fn set_high_priority_channel( &mut self, val: ChannelctrlSetHighPriorityChannel, )
Setting a bit in this field causes the corresponding channel to have high-priority arbitration
Sourcepub const fn ch0_irq_merged(&self) -> bool
pub const fn ch0_irq_merged(&self) -> bool
Indicates that the interrupt for channel 0 must be merged with the other interrupts on the shared dcp_irq interrupt
Sourcepub const fn set_ch0_irq_merged(&mut self, val: bool)
pub const fn set_ch0_irq_merged(&mut self, val: bool)
Indicates that the interrupt for channel 0 must be merged with the other interrupts on the shared dcp_irq interrupt