nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Dbgselect

Struct Dbgselect 

#[repr(transparent)]
pub struct Dbgselect(pub u32);
DCP debug select register

Tuple Fields

0: u32

Implementations

Source

impl Dbgselect

pub const fn index(&self) -> Index

Selects a value to read via the debug data register.

pub const fn set_index(&mut self, val: Index)

Selects a value to read via the debug data register.