#[repr(transparent)]pub struct Packet2(pub u32);Expand description
DCP work packet 2 status register
Tuple Fields
0: u32Implementations
Sourceimpl Packet2
impl Packet2
Sourcepub const fn cipher_select(&self) -> CipherSelect
pub const fn cipher_select(&self) -> CipherSelect
Cipher selection field
Sourcepub const fn set_cipher_select(&mut self, val: CipherSelect)
pub const fn set_cipher_select(&mut self, val: CipherSelect)
Cipher selection field
Sourcepub const fn cipher_mode(&self) -> CipherMode
pub const fn cipher_mode(&self) -> CipherMode
Cipher mode selection field. Reflects the mode of operation for the cipher operations.
Sourcepub const fn set_cipher_mode(&mut self, val: CipherMode)
pub const fn set_cipher_mode(&mut self, val: CipherMode)
Cipher mode selection field. Reflects the mode of operation for the cipher operations.
Sourcepub const fn key_select(&self) -> KeySelect
pub const fn key_select(&self) -> KeySelect
Key selection field
Sourcepub const fn set_key_select(&mut self, val: KeySelect)
pub const fn set_key_select(&mut self, val: KeySelect)
Key selection field
Sourcepub const fn hash_select(&self) -> HashSelect
pub const fn hash_select(&self) -> HashSelect
Hash Selection Field
Sourcepub const fn set_hash_select(&mut self, val: HashSelect)
pub const fn set_hash_select(&mut self, val: HashSelect)
Hash Selection Field
Sourcepub const fn cipher_cfg(&self) -> u8
pub const fn cipher_cfg(&self) -> u8
Cipher configuration bits. Optional configuration bits are required for the ciphers.
Sourcepub const fn set_cipher_cfg(&mut self, val: u8)
pub const fn set_cipher_cfg(&mut self, val: u8)
Cipher configuration bits. Optional configuration bits are required for the ciphers.