nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Packet6

Struct Packet6 

#[repr(transparent)]
pub struct Packet6(pub u32);
DCP work packet 6 status register

Tuple Fields

0: u32

Implementations

Source

impl Packet6

pub const fn addr(&self) -> u32

This regiser reflects the payload pointer for the current control packet.

pub const fn set_addr(&mut self, val: u32)

This regiser reflects the payload pointer for the current control packet.