#[repr(transparent)]pub struct StatTog(pub u32);Expand description
DCP status register
Tuple Fields
0: u32Implementations
Sourceimpl StatTog
impl StatTog
Sourcepub const fn set_irq(&mut self, val: u8)
pub const fn set_irq(&mut self, val: u8)
Indicates which channels have pending interrupt requests
Sourcepub const fn ready_channels(&self) -> StatTogReadyChannels
pub const fn ready_channels(&self) -> StatTogReadyChannels
Indicates which channels are ready to proceed with a transfer (the active channel is also included)
Sourcepub const fn set_ready_channels(&mut self, val: StatTogReadyChannels)
pub const fn set_ready_channels(&mut self, val: StatTogReadyChannels)
Indicates which channels are ready to proceed with a transfer (the active channel is also included)
Sourcepub const fn cur_channel(&self) -> StatTogCurChannel
pub const fn cur_channel(&self) -> StatTogCurChannel
Current (active) channel (encoded)
Sourcepub const fn set_cur_channel(&mut self, val: StatTogCurChannel)
pub const fn set_cur_channel(&mut self, val: StatTogCurChannel)
Current (active) channel (encoded)
Sourcepub const fn otp_key_ready(&self) -> bool
pub const fn otp_key_ready(&self) -> bool
When set, it indicates that the OTP key is shifted from the fuse block and is ready for use.
Sourcepub const fn set_otp_key_ready(&mut self, val: bool)
pub const fn set_otp_key_ready(&mut self, val: bool)
When set, it indicates that the OTP key is shifted from the fuse block and is ready for use.