#[repr(transparent)]pub struct Version(pub u32);Expand description
DCP version register
Tuple Fields
0: u32Implementations
Sourceimpl Version
impl Version
Sourcepub const fn step(&self) -> u16
pub const fn step(&self) -> u16
Fixed read-only value reflecting the stepping of the version of the design implementation.
Sourcepub const fn set_step(&mut self, val: u16)
pub const fn set_step(&mut self, val: u16)
Fixed read-only value reflecting the stepping of the version of the design implementation.
Sourcepub const fn minor(&self) -> u8
pub const fn minor(&self) -> u8
Fixed read-only value reflecting the MINOR version of the design implementation.
Sourcepub const fn set_minor(&mut self, val: u8)
pub const fn set_minor(&mut self, val: u8)
Fixed read-only value reflecting the MINOR version of the design implementation.