#[repr(transparent)]pub struct Capability1(pub u32);Expand description
DCP capability 1 register
Tuple Fields
0: u32Implementations
Sourceimpl Capability1
impl Capability1
Sourcepub const fn cipher_algorithms(&self) -> CipherAlgorithms
pub const fn cipher_algorithms(&self) -> CipherAlgorithms
One-hot field indicating which cipher algorithms are available
Sourcepub const fn set_cipher_algorithms(&mut self, val: CipherAlgorithms)
pub const fn set_cipher_algorithms(&mut self, val: CipherAlgorithms)
One-hot field indicating which cipher algorithms are available
Sourcepub const fn hash_algorithms(&self) -> HashAlgorithms
pub const fn hash_algorithms(&self) -> HashAlgorithms
One-hot field indicating which hashing features are implemented in the hardware
Sourcepub const fn set_hash_algorithms(&mut self, val: HashAlgorithms)
pub const fn set_hash_algorithms(&mut self, val: HashAlgorithms)
One-hot field indicating which hashing features are implemented in the hardware