#[repr(transparent)]pub struct CtrlClr(pub u32);Expand description
DCP control register 0
Tuple Fields
0: u32Implementations
Sourceimpl CtrlClr
impl CtrlClr
Sourcepub const fn channel_interrupt_enable(&self) -> CtrlClrChannelInterruptEnable
pub const fn channel_interrupt_enable(&self) -> CtrlClrChannelInterruptEnable
Per-channel interrupt enable bit
Sourcepub const fn set_channel_interrupt_enable(
&mut self,
val: CtrlClrChannelInterruptEnable,
)
pub const fn set_channel_interrupt_enable( &mut self, val: CtrlClrChannelInterruptEnable, )
Per-channel interrupt enable bit
Sourcepub const fn enable_context_switching(&self) -> bool
pub const fn enable_context_switching(&self) -> bool
Enable automatic context switching for the channels
Sourcepub const fn set_enable_context_switching(&mut self, val: bool)
pub const fn set_enable_context_switching(&mut self, val: bool)
Enable automatic context switching for the channels
Sourcepub const fn enable_context_caching(&self) -> bool
pub const fn enable_context_caching(&self) -> bool
The software must set this bit to enable the caching of contexts between the operations
Sourcepub const fn set_enable_context_caching(&mut self, val: bool)
pub const fn set_enable_context_caching(&mut self, val: bool)
The software must set this bit to enable the caching of contexts between the operations
Sourcepub const fn gather_residual_writes(&self) -> bool
pub const fn gather_residual_writes(&self) -> bool
The software must set this bit to enable the ragged writes to the unaligned buffers to be gathered between multiple write operations
Sourcepub const fn set_gather_residual_writes(&mut self, val: bool)
pub const fn set_gather_residual_writes(&mut self, val: bool)
The software must set this bit to enable the ragged writes to the unaligned buffers to be gathered between multiple write operations
Sourcepub const fn present_sha(&self) -> CtrlClrPresentSha
pub const fn present_sha(&self) -> CtrlClrPresentSha
Indicates whether the SHA1/SHA2 functions are present.
Sourcepub const fn set_present_sha(&mut self, val: CtrlClrPresentSha)
pub const fn set_present_sha(&mut self, val: CtrlClrPresentSha)
Indicates whether the SHA1/SHA2 functions are present.
Sourcepub const fn present_crypto(&self) -> CtrlClrPresentCrypto
pub const fn present_crypto(&self) -> CtrlClrPresentCrypto
Indicates whether the crypto (cipher/hash) functions are present.
Sourcepub const fn set_present_crypto(&mut self, val: CtrlClrPresentCrypto)
pub const fn set_present_crypto(&mut self, val: CtrlClrPresentCrypto)
Indicates whether the crypto (cipher/hash) functions are present.
Sourcepub const fn set_clkgate(&mut self, val: bool)
pub const fn set_clkgate(&mut self, val: bool)
This bit must be set to zero for a normal operation
Sourcepub const fn set_sftrst(&mut self, val: bool)
pub const fn set_sftrst(&mut self, val: bool)
Set this bit to zero to enable a normal DCP operation